@@ -4,7 +4,8 @@ import hashlib
 import logging
 import re
 import sys
-from typing import Any, Dict, Iterator, List, Optional, Tuple, Union
+from collections.abc import Iterator
+from typing import Any, Optional, Union
 from urllib.parse import urlparse
 
 from requests.structures import CaseInsensitiveDict
@@ -68,7 +69,7 @@ def bucket_name_from_url(url: str) -> Optional[str]:  # type: ignore
 
 
 # 'owi-common-cf', 'snippets/test.json' = bucket_and_name_from_url('s3://owi-common-cf/snippets/test.json')
-def bucket_and_name_from_url(url: str) -> Union[Tuple[str, str], Tuple[None, None]]:
+def bucket_and_name_from_url(url: str) -> Union[tuple[str, str], tuple[None, None]]:
     prefix = "s3://"
     if url.startswith(prefix):
         bucket_name = url[len(prefix) : url.index("/", len(prefix))]
@@ -93,7 +94,7 @@ def parse_region_from_url(url: str, use_default_region: bool = True) -> str:
     return region
 
 
-def metadata_from_headers(headers: Dict[str, Any]) -> CaseInsensitiveDict:  # type: ignore
+def metadata_from_headers(headers: dict[str, Any]) -> CaseInsensitiveDict:  # type: ignore
     metadata = CaseInsensitiveDict()  # type: ignore
     meta_regex = re.compile(r"^x-amz-meta-([a-zA-Z0-9\-_.]+)$", flags=re.IGNORECASE)
     for header in headers.keys():
@@ -120,7 +121,7 @@ class _VersionedKeyStore(dict):  # type: ignore
     https://github.com/django/django/blob/70576740b0bb5289873f5a9a9a4e1a26b2c330e5/django/utils/datastructures.py#L282
     """
 
-    def __sgetitem__(self, key: str) -> List[Any]:
+    def __sgetitem__(self, key: str) -> list[Any]:
         return super().__getitem__(key)
 
     def pop(self, key: str) -> None:  # type: ignore
@@ -168,7 +169,7 @@ class _VersionedKeyStore(dict):  # type: ignore
 
         super().__setitem__(key, list_)
 
-    def _iteritems(self) -> Iterator[Tuple[str, Any]]:
+    def _iteritems(self) -> Iterator[tuple[str, Any]]:
         for key in self._self_iterable():
             yield key, self[key]
 
@@ -176,7 +177,7 @@ class _VersionedKeyStore(dict):  # type: ignore
         for key in self._self_iterable():
             yield self[key]
 
-    def _iterlists(self) -> Iterator[Tuple[str, List[Any]]]:
+    def _iterlists(self) -> Iterator[tuple[str, list[Any]]]:
         for key in self._self_iterable():
             yield key, self.getlist(key)
 
@@ -186,7 +187,7 @@ class _VersionedKeyStore(dict):  # type: ignore
             size += sys.getsizeof(val)
         return size
 
-    def _self_iterable(self) -> Dict[str, Any]:
+    def _self_iterable(self) -> dict[str, Any]:
         # to enable concurrency, return a copy, to avoid "dictionary changed size during iteration"
         # TODO: look into replacing with a locking mechanism, potentially
         return dict(self)
@@ -221,7 +222,7 @@ def _hash(fn: Any, args: Any) -> bytes:
     return fn(*args, usedforsecurity=False).digest()
 
 
-def cors_matches_origin(origin_header: str, allowed_origins: List[str]) -> bool:
+def cors_matches_origin(origin_header: str, allowed_origins: list[str]) -> bool:
     if "*" in allowed_origins:
         return True
     if origin_header in allowed_origins:
