@@ -43,3 +43,26 @@ class VectorBucketAlreadyExists(ServiceException):
 
     def __init__(self) -> None:
         super().__init__("A vector bucket with the specified name already exists")
+
+
+class VectorBucketNotEmpty(ServiceException):
+    code = "ConflictException"
+
+    def __init__(self) -> None:
+        super().__init__("The specified vector bucket is not empty")
+
+
+class VectorBucketPolicyNotFound(ServiceException):
+    code = "NotFoundException"
+
+    def __init__(self) -> None:
+        super().__init__("The specified vector bucket policy could not be found")
+
+
+class VectorWrongDimension(ServiceException):
+    code = "ValidationException"
+
+    def __init__(self, key: str, actual: int, provided: int):
+        super().__init__(
+            f"Invalid record for key '{key}': vector must have length {actual}, but has length {provided}"
+        )
