@@ -1,19 +1,19 @@
 import boto3
 
-from moto import mock_apigatewayv2
+from moto import mock_aws
 
 
-@mock_apigatewayv2
+@mock_aws
 def test_create_api_with_tags():
     client = boto3.client("apigatewayv2", region_name="eu-west-1")
     resp = client.create_api(
         Name="test-api", ProtocolType="HTTP", Tags={"key1": "value1", "key2": "value2"}
     )
 
-    resp.should.have.key("Tags").equals({"key1": "value1", "key2": "value2"})
+    assert resp["Tags"] == {"key1": "value1", "key2": "value2"}
 
 
-@mock_apigatewayv2
+@mock_aws
 def test_tag_resource():
     client = boto3.client("apigatewayv2", region_name="eu-west-1")
     api_id = client.create_api(Name="test-api", ProtocolType="HTTP")["ApiId"]
@@ -25,10 +25,10 @@ def test_tag_resource():
 
     resp = client.get_api(ApiId=api_id)
 
-    resp.should.have.key("Tags").equals({"key1": "value1", "key2": "value2"})
+    assert resp["Tags"] == {"key1": "value1", "key2": "value2"}
 
 
-@mock_apigatewayv2
+@mock_aws
 def test_get_tags():
     client = boto3.client("apigatewayv2", region_name="eu-west-2")
     api_id = client.create_api(Name="test-api", ProtocolType="HTTP")["ApiId"]
@@ -40,10 +40,10 @@ def test_get_tags():
 
     resp = client.get_tags(ResourceArn=resource_arn)
 
-    resp.should.have.key("Tags").equals({"key1": "value1", "key2": "value2"})
+    assert resp["Tags"] == {"key1": "value1", "key2": "value2"}
 
 
-@mock_apigatewayv2
+@mock_aws
 def test_untag_resource():
     client = boto3.client("apigatewayv2", region_name="eu-west-2")
     api_id = client.create_api(
@@ -59,4 +59,4 @@ def test_untag_resource():
 
     resp = client.get_tags(ResourceArn=resource_arn)
 
-    resp.should.have.key("Tags").equals({"key1": "value1", "key3": "value3"})
+    assert resp["Tags"] == {"key1": "value1", "key3": "value3"}
