@@ -481,15 +481,18 @@ def test_create_redis_cache_cluster():
 
     cache_cluster_id = "test-cache-cluster"
     cache_cluster_engine = "redis"
+    cache_cluster_node_type = "cache.r6g.large"
     cache_cluster_num_cache_nodes = 5
 
     resp = client.create_cache_cluster(
         CacheClusterId=cache_cluster_id,
         Engine=cache_cluster_engine,
+        CacheNodeType=cache_cluster_node_type,
         NumCacheNodes=cache_cluster_num_cache_nodes,
         AutoMinorVersionUpgrade=True,
         TransitEncryptionEnabled=True,
     )
+
     cache_cluster = resp["CacheCluster"]
 
     if cache_cluster["CacheClusterId"] == cache_cluster_id:
@@ -510,12 +513,14 @@ def test_create_memcached_cache_cluster():
     test_memcached_cache_cluster_exist = False
 
     cache_cluster_id = "test-cache-cluster"
+    cache_cluster_node_type = "cache.t3.micro"
     cache_cluster_engine = "memcached"
     cache_cluster_num_cache_nodes = 5
 
     resp = client.create_cache_cluster(
         CacheClusterId=cache_cluster_id,
         Engine=cache_cluster_engine,
+        CacheNodeType=cache_cluster_node_type,
         NumCacheNodes=cache_cluster_num_cache_nodes,
     )
     cache_cluster = resp["CacheCluster"]
@@ -535,22 +540,46 @@ def test_create_duplicate_cache_cluster():
 
     cache_cluster_id = "test-cache-cluster"
     cache_cluster_engine = "memcached"
+    cache_cluster_node_type = "cache.r6g.large"
 
     client.create_cache_cluster(
         CacheClusterId=cache_cluster_id,
         Engine=cache_cluster_engine,
+        CacheNodeType=cache_cluster_node_type,
     )
 
     with pytest.raises(ClientError) as exc:
         client.create_cache_cluster(
             CacheClusterId=cache_cluster_id,
             Engine=cache_cluster_engine,
+            CacheNodeType=cache_cluster_node_type,
         )
     err = exc.value.response["Error"]
     assert err["Code"] == "CacheClusterAlreadyExists"
     assert err["Message"] == f"Cache cluster {cache_cluster_id} already exists."
 
 
+@mock_aws
+def test_create_cache_cluster_invalid_param_value():
+    client = boto3.client("elasticache", region_name="us-east-2")
+
+    cache_cluster_id = "test-cache-cluster"
+    cache_cluster_engine = "redis"
+
+    with pytest.raises(ClientError) as exc:
+        client.create_cache_cluster(
+            CacheClusterId=cache_cluster_id,
+            Engine=cache_cluster_engine,
+        )
+
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidParameterValue"
+    assert (
+        err["Message"]
+        == "The parameter CacheNodeType must be provided and must not be null."
+    )
+
+
 @mock_aws
 def test_describe_all_cache_clusters():
     client = boto3.client("elasticache", region_name="us-east-2")
@@ -562,6 +591,7 @@ def test_describe_all_cache_clusters():
         client.create_cache_cluster(
             CacheClusterId=f"test-cache-cluster-{i}",
             Engine="memcached",
+            CacheNodeType="cache.t3.micro",
             NumCacheNodes=5,
         )
 
@@ -574,10 +604,7 @@ def test_describe_all_cache_clusters():
         if cache_cluster["CacheClusterId"] == f"test-cache-cluster-{i}":
             match_number = match_number + 1
 
-    if match_number == (num_clusters):
-        assert True
-    else:
-        assert False
+    assert match_number == num_clusters
 
 
 @mock_aws
@@ -588,17 +615,20 @@ def test_describe_specific_cache_clusters():
 
     cache_cluster_id = "test-cache-cluster"
     cache_cluster_engine = "memcached"
+    cache_cluster_node_type = "cache.t3.micro"
     cache_cluster_num_cache_nodes = 5
 
     client.create_cache_cluster(
         CacheClusterId=cache_cluster_id,
         Engine=cache_cluster_engine,
+        CacheNodeType=cache_cluster_node_type,
         NumCacheNodes=cache_cluster_num_cache_nodes,
     )
 
     client.create_cache_cluster(
         CacheClusterId="test-cache-cluster-2",
         Engine=cache_cluster_engine,
+        CacheNodeType=cache_cluster_node_type,
         NumCacheNodes=cache_cluster_num_cache_nodes,
     )
 
@@ -621,11 +651,13 @@ def test_describe_unknown_cache_cluster():
     cache_cluster_id = "test-cache-cluster"
     cache_cluster_id_unknown = "unknown-cache-cluster"
     cache_cluster_engine = "memcached"
+    cache_cluster_node_type = "cache.t3.micro"
     cache_cluster_num_cache_nodes = 5
 
     client.create_cache_cluster(
         CacheClusterId=cache_cluster_id,
         Engine=cache_cluster_engine,
+        CacheNodeType=cache_cluster_node_type,
         NumCacheNodes=cache_cluster_num_cache_nodes,
     )
 
@@ -644,11 +676,13 @@ def test_delete_cache_cluster():
 
     cache_cluster_id = "test-cache-cluster"
     cache_cluster_engine = "memcached"
+    cache_cluster_node_type = "cache.t3.micro"
     cache_cluster_num_cache_nodes = 5
 
     client.create_cache_cluster(
         CacheClusterId=cache_cluster_id,
         Engine=cache_cluster_engine,
+        CacheNodeType=cache_cluster_node_type,
         NumCacheNodes=cache_cluster_num_cache_nodes,
     )
 
@@ -667,11 +701,13 @@ def test_delete_unknown_cache_cluster():
     cache_cluster_id = "test-cache-cluster"
     cache_cluster_id_unknown = "unknown-cache-cluster"
     cache_cluster_engine = "memcached"
+    cache_cluster_node_type = "cache.t3.micro"
     cache_cluster_num_cache_nodes = 5
 
     client.create_cache_cluster(
         CacheClusterId=cache_cluster_id,
         Engine=cache_cluster_engine,
+        CacheNodeType=cache_cluster_node_type,
         NumCacheNodes=cache_cluster_num_cache_nodes,
     )
 
@@ -694,6 +730,7 @@ def test_list_tags_cache_cluster():
     test_instance = conn.create_cache_cluster(
         CacheClusterId="test-cache-cluster",
         Engine="memcached",
+        CacheNodeType="cache.t3.micro",
         NumCacheNodes=2,
         Tags=[{"Key": "foo", "Value": "bar"}, {"Key": "foo1", "Value": "bar1"}],
         SecurityGroupIds=["sg-1234"],
@@ -1189,11 +1226,7 @@ def test_create_replication_group_cluster_enabled():
     )
 
     assert len(replication_group["MemberClustersOutpostArns"]) == 3
-
-    if replication_group["ClusterEnabled"]:
-        assert True
-    else:
-        assert False
+    assert replication_group["ClusterEnabled"]
 
 
 @mock_aws
@@ -1306,7 +1339,7 @@ def test_describe_replication_groups_pagination():
         + page2["ReplicationGroups"]
         + page3["ReplicationGroups"]
     )
-    assert len(set([group["ReplicationGroupId"] for group in whole_book])) == 10
+    assert len({group["ReplicationGroupId"] for group in whole_book}) == 10
 
 
 @mock_aws
@@ -1361,10 +1394,7 @@ def test_describe_replication_groups_cluster_disabled():
     assert replication_group["SnapshottingClusterId"] == f"{replication_group_id}-002"
     assert replication_group["MultiAZ"] == "enabled"
     assert replication_group["SnapshotRetentionLimit"] == 1
-    if not replication_group["ClusterEnabled"]:
-        assert True
-    else:
-        assert False
+    assert not replication_group["ClusterEnabled"]
     assert replication_group["CacheNodeType"] == "cache.t4g.micro"
     assert (
         replication_group["ARN"]
@@ -1509,7 +1539,7 @@ def test_delete_replication_group():
         ReplicationGroupId=replication_group_id,
         ReplicationGroupDescription="test replication group",
         Engine="redis",
-        CacheNodeType="cache.t4g.micro",
+        CacheNodeType="cache.t4g.small",
         NumNodeGroups=1,
         ReplicasPerNodeGroup=2,
         AutomaticFailoverEnabled=True,
@@ -1556,6 +1586,7 @@ def test_create_cache_cluster_with_auth_token():
     client.create_cache_cluster(
         CacheClusterId=cluster_id,
         Engine="redis",
+        CacheNodeType="cache.t4g.small",
         NumCacheNodes=1,
         AuthToken="a-very-secure-password-for-testing",
     )
@@ -1573,6 +1604,7 @@ def test_create_cache_cluster_without_auth_token():
     client.create_cache_cluster(
         CacheClusterId=cluster_id,
         Engine="redis",
+        CacheNodeType="cache.t4g.small",
         NumCacheNodes=1,
     )
 
@@ -1591,6 +1623,7 @@ def test_create_snapshot():
     client.create_cache_cluster(
         CacheClusterId=cluster_id,
         Engine="redis",
+        CacheNodeType="cache.t4g.small",
         NumCacheNodes=1,
     )
 
@@ -1658,6 +1691,7 @@ def test_create_snapshot_with_vpc():
     client.create_cache_cluster(
         CacheClusterId="test-cluster",
         Engine="redis",
+        CacheNodeType="cache.t4g.small",
         NumCacheNodes=1,
         CacheSubnetGroupName="test-subnet-group",
     )
@@ -1680,6 +1714,7 @@ def test_create_snapshot_already_exists():
     client.create_cache_cluster(
         CacheClusterId=cluster_id,
         Engine="redis",
+        CacheNodeType="cache.t4g.small",
         NumCacheNodes=1,
     )
 
@@ -1769,6 +1804,7 @@ def test_describe_snapshots():
     client.create_cache_cluster(
         CacheClusterId=cluster_id,
         Engine="redis",
+        CacheNodeType="cache.t4g.small",
         NumCacheNodes=1,
     )
 
@@ -1851,6 +1887,7 @@ def test_delete_snapshot():
     client.create_cache_cluster(
         CacheClusterId=cluster_id,
         Engine="redis",
+        CacheNodeType="cache.t4g.small",
         NumCacheNodes=1,
     )
 
@@ -1890,6 +1927,7 @@ def test_list_tags_snapshot():
     client.create_cache_cluster(
         CacheClusterId=cluster_id,
         Engine="redis",
+        CacheNodeType="cache.t4g.small",
         NumCacheNodes=1,
     )
 
