@@ -1,12 +1,12 @@
-import boto3
-import sure  # noqa # pylint: disable=unused-import
 import time
 
-from moto import mock_glacier
+import boto3
+
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
-@mock_glacier
+@mock_aws
 def test_initiate_job():
     client = boto3.client("glacier", region_name="us-west-2")
     client.create_vault(vaultName="myname")
@@ -17,23 +17,21 @@ def test_initiate_job():
         vaultName="myname",
         jobParameters={"ArchiveId": archive["archiveId"], "Type": "archive-retrieval"},
     )
-    job["ResponseMetadata"]["HTTPStatusCode"].should.equal(202)
+    assert job["ResponseMetadata"]["HTTPStatusCode"] == 202
 
     headers = job["ResponseMetadata"]["HTTPHeaders"]
-    headers.should.have.key("x-amz-job-id")
+    assert "x-amz-job-id" in headers
     # Should be an exact match, but Flask adds 'http' to the start of the Location-header
-    headers.should.have.key("location").match(
-        "//vaults/myname/jobs/" + headers["x-amz-job-id"]
-    )
+    assert headers["location"] == "//vaults/myname/jobs/" + headers["x-amz-job-id"]
 
     # Don't think this is correct - the spec says no body is returned, only headers
     # https://docs.aws.amazon.com/amazonglacier/latest/dev/api-initiate-job-post.html
-    job.should.have.key("jobId")
-    job.should.have.key("location")
+    assert "jobId" in job
+    assert "location" in job
 
 
-@mock_glacier
-def test_describe_job_boto3():
+@mock_aws
+def test_describe_job():
     client = boto3.client("glacier", region_name="us-west-2")
     client.create_vault(vaultName="myname")
 
@@ -46,21 +44,21 @@ def test_describe_job_boto3():
     job_id = job["jobId"]
 
     describe = client.describe_job(vaultName="myname", jobId=job_id)
-    describe.should.have.key("JobId").equal(job_id)
-    describe.should.have.key("Action").equal("ArchiveRetrieval")
-    describe.should.have.key("ArchiveId").equal(archive["archiveId"])
-    describe.should.have.key("VaultARN").equal(
-        f"arn:aws:glacier:us-west-2:{ACCOUNT_ID}:vaults/myname"
+    assert describe["JobId"] == job_id
+    assert describe["Action"] == "ArchiveRetrieval"
+    assert describe["ArchiveId"] == archive["archiveId"]
+    assert (
+        describe["VaultARN"] == f"arn:aws:glacier:us-west-2:{ACCOUNT_ID}:vaults/myname"
     )
-    describe.should.have.key("CreationDate")
-    describe.should.have.key("Completed").equal(False)
-    describe.should.have.key("StatusCode").equal("InProgress")
-    describe.should.have.key("ArchiveSizeInBytes").equal(0)
-    describe.should.have.key("InventorySizeInBytes").equal(0)
-    describe.should.have.key("Tier").equal("Standard")
+    assert "CreationDate" in describe
+    assert describe["Completed"] is False
+    assert describe["StatusCode"] == "InProgress"
+    assert describe["ArchiveSizeInBytes"] == 0
+    assert describe["InventorySizeInBytes"] == 0
+    assert describe["Tier"] == "Standard"
 
 
-@mock_glacier
+@mock_aws
 def test_list_jobs():
     client = boto3.client("glacier", region_name="us-west-2")
     client.create_vault(vaultName="myname")
@@ -81,30 +79,30 @@ def test_list_jobs():
 
     # Verify the created jobs are in this list
     found_jobs = [j["JobId"] for j in jobs]
-    found_jobs.should.contain(job1["jobId"])
-    found_jobs.should.contain(job2["jobId"])
+    assert job1["jobId"] in found_jobs
+    assert job2["jobId"] in found_jobs
 
     found_job1 = [j for j in jobs if j["JobId"] == job1["jobId"]][0]
-    found_job1.should.have.key("ArchiveId").equal(archive1["archiveId"])
+    assert found_job1["ArchiveId"] == archive1["archiveId"]
     found_job2 = [j for j in jobs if j["JobId"] == job2["jobId"]][0]
-    found_job2.should.have.key("ArchiveId").equal(archive2["archiveId"])
+    assert found_job2["ArchiveId"] == archive2["archiveId"]
 
     # Verify all jobs follow the correct format
     for job in jobs:
-        job.should.have.key("JobId")
-        job.should.have.key("Action")
-        job.should.have.key("ArchiveId")
-        job.should.have.key("VaultARN")
-        job.should.have.key("CreationDate")
-        job.should.have.key("ArchiveSizeInBytes")
-        job.should.have.key("Completed")
-        job.should.have.key("StatusCode")
-        job.should.have.key("InventorySizeInBytes")
-        job.should.have.key("Tier")
+        assert "JobId" in job
+        assert "Action" in job
+        assert "ArchiveId" in job
+        assert "VaultARN" in job
+        assert "CreationDate" in job
+        assert "ArchiveSizeInBytes" in job
+        assert "Completed" in job
+        assert "StatusCode" in job
+        assert "InventorySizeInBytes" in job
+        assert "Tier" in job
 
 
-@mock_glacier
-def test_get_job_output_boto3():
+@mock_aws
+def test_get_job_output():
     client = boto3.client("glacier", region_name="us-west-2")
     client.create_vault(vaultName="myname")
 
@@ -124,9 +122,9 @@ def test_get_job_output_boto3():
         except Exception:
             time.sleep(1)
 
-    output.should.have.key("status").equal(200)
-    output.should.have.key("contentType").equal("application/octet-stream")
-    output.should.have.key("body")
+    assert output["status"] == 200
+    assert output["contentType"] == "application/octet-stream"
+    assert "body" in output
 
     body = output["body"].read().decode("utf-8")
-    body.should.equal("contents of archive")
+    assert body == "contents of archive"
